.. _api_dul_primitives_apabort:

A-P-ABORT
=========

.. currentmodule:: pynetdicom.pdu_primitives

The ACSE A-P-ABORT service shall be used by the Upper Layer service provider
to signal the abnormal release of the association due to problems in services
at the Presentation Layer and below.

.. autosummary::
   :toctree: generated/

   A_P_ABORT
